@@ -10,12 +10,22 @@ from azure.storage.blob import BlobServiceClient  # , BlobClient, ContainerClien
 import uuid
 import pandas
 import requests
-# import sys
+import logging
+import sys
 from .._utils._constants import ACCOUNT, api_prefix
 from .._utils._utils import ApiInputs
 
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.DEBUG)
+consoleHandler = logging.StreamHandler(stream=sys.stdout)
+consoleHandler.setLevel(logging.INFO)
+
+logger.addHandler(consoleHandler)
+formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s  %(levelname)s: %(message)s',
+                              datefmt='%Y-%m-%dT%H:%M:%S')
+consoleHandler.setFormatter(formatter)
+
 
-# class Platform:
 class Queue:
     """ """
     @staticmethod
@@ -94,7 +104,7 @@ class Blob:
         container_client = blob_service_client.get_container_client(container)
         blob_list = container_client.list_blobs(name_starts_with=prefix)
         for blob in blob_list:
-            print(blob.name + ' - ' + str(blob.last_modified))
+            logger.info('%s - %s', blob.name,  str(blob.last_modified))
         return True
 
     @staticmethod
@@ -119,8 +129,9 @@ class Blob:
         con_string = _get_connection_string(api_inputs, account)
         blob_service_client = BlobServiceClient.from_connection_string(con_string)
         container_client = blob_service_client.get_container_client(container)
-        print("Start Downloading")
+
         blob_client = container_client.get_blob_client(blob_name)
+
         return blob_client.download_blob().readall()
 
     @staticmethod
@@ -163,7 +174,7 @@ class Blob:
         for current_data_frame in list_chunked_df:
             item_counter += 1
             blob_name = upload_path + str(item_counter) + ".csv"
-            print("         Uploading ... " + blob_name)
+            logger.info("Uploading ... %s", blob_name)
             blob_client = container_client.get_blob_client(blob_name)
             data_csv = bytes(current_data_frame.to_csv(line_terminator='\r\n', index=False, header=False),
                              encoding='utf-8')
