@@ -82,8 +82,9 @@ def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema,
         schema.validate(raw_df, lazy=True)
     except pandera.errors.SchemaErrors as err:
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/DataFeedErrors/FileFormat"
-        print(err.failure_cases)
+        logger.error('Schema errors present: %s', err.failure_cases)
         schema_error = err.failure_cases
+
         response = requests.post(url, data=schema_error.to_json(orient='records'), headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
         if response.status_code != 200:
