@@ -75,7 +75,7 @@ consoleHandler = logging.StreamHandler(sys.stdout)
 consoleHandler.setLevel(logging.INFO)
 
 logger.addHandler(consoleHandler)
-formatter = logging.Formatter('%(asctime)s  %(name)s.%(funcName)s  %(levelname)s: %(message)s',
+formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s  %(levelname)s: %(message)s',
                               datefmt='%Y-%m-%dT%H:%M:%S')
 consoleHandler.setFormatter(formatter)
 
@@ -320,9 +320,8 @@ class Automation:
                 "Driver must be an implementation of the QueueTask (Task).")
             return False
 
-        print()
-        print("Switch.Automation: Running Queue for  " + type(task).__name__ + ' (' + str(task.id) +
-              ') using Queue Name ' + task.queue_name)
+        logger.info("Running queue for  %s (%s) using queue name: %s", str(type(task).__name__), str(task.id),
+                    str(task.queue_name))
         
         task.start(api_inputs)
 
@@ -346,7 +345,7 @@ class Automation:
                     
                     if consume_all_messages == False:
                         break
-        print(f"Switch.Automation: Total messages consumed:  {str(message_count)} ")
+        logger.info('Total messages consumed: %s', str(message_count))
 
     @staticmethod
     def reserve_instance(task: Task, api_inputs: ApiInputs, data_feed_id: uuid.UUID, minutes_to_reserve: int = 10):
@@ -376,9 +375,8 @@ class Automation:
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        print("Switch.Automation: Reserving Testing Instance for " + type(
-            task).__name__ + ' (' + str(task.id) + ') on Data Feed Id (' + str(data_feed_id) + ')')
-        print()
+        logger.info("Reserving a testing instance for %s (%s) on Data Feed Id (%s). ", str(type(task).__name__),
+                    str(task.id), str(data_feed_id))
 
         headers = {
             'x-functions-key': api_inputs.api_key,
@@ -438,9 +436,7 @@ class Automation:
                 'LogicModule.')
             return {}, pandas.DataFrame()
 
-        print("Switch.Automation: Registering " + type(
-            task).__name__ + ' (' + str(task.id) + ')' + ' to the Switch Driver Library: ')
-        print()
+        logger.info("Registering %s (%s) to the Switch Driver Library: ", str(type(task).__name__), str(task.id))
 
         json_payload_verify = {
             "driverId": task.id,
@@ -566,21 +562,13 @@ class Automation:
                     api_inputs.api_project_id)
 
         if not _is_valid_regex(email_subject_regex):
-            # print("Automation.deploy_as_email_data_feed: " + email_subject_regex + "is not a valid Regular "
-            #                                                                        "Expression.")
-            # return False
             logger.error("%s is not valid regex.", email_subject_regex)
             return pandas.DataFrame()
 
         if email_address_domain == "switchautomation.com":
-            # print("Automation.deploy_as_email_data_feed: Emails can only be received from the " + email_address_domain
-            #       + " domain.")
             logger.info("Emails can only be received from the %s domain.", email_address_domain)
 
         if "@" in email_address_domain:
-            # print(
-            #     "Automation.deploy_as_email_data_feed: Do not include the @ in the email_address_domain parameter.")
-            # return False
             logger.error("Do not include the @ in the email_address_domain parameter. ")
             return pandas.DataFrame()
 
@@ -620,9 +608,6 @@ class Automation:
         df = pandas.read_json(response.text, typ='Series')
         return df
 
-        # Create Data Feed for Specified ApiProject Id
-        # print the Data Centre and ApiProject Name
-
     @staticmethod
     def deploy_as_ftp_data_feed(task, api_inputs: ApiInputs, ftp_user_name, ftp_password,
                                 queue_name: QUEUE_NAME = "task", expected_delivery: EXPECTED_DELIVERY = "15min"):
@@ -805,9 +790,7 @@ class Automation:
 
         time_type = expected_deliveries[1].lower()[:3]
         if time_type != 'min' and time_type != 'hour' and time_type != 'day':
-            # print("Automation.deploy_on_timer: Expected Delivery Time Type must start with min, hour, day")
             logger.error("The expected_delivery time type must start with one of: min, hour, day. ")
-            # return False
             return pandas.DataFrame()
 
         logger.info('Deploy %s (%s) on timer for ApiProjectID: %s and schedule: %s.', type(task).__name__,
@@ -888,7 +871,6 @@ class Automation:
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/CancelTask/" + \
             deploy_type + "/" + task.id
-        print(url)
         response = requests.get(url, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
         if response.status_code != 200:
